@@ -73,17 +73,17 @@ def h2b(s: Hexstr) -> bytearray:
 
 def b2h(b: bytearray) -> hexstr:
     """convert from a sequence of bytes to a string of hex nibbles"""
-    return hexstr(''.join(['%02x' % (x) for x in b]))
+    return hexstr(b.hex())
 
 
 def h2i(s: Hexstr) -> List[int]:
     """convert from a string of hex nibbles to a list of integers"""
-    return [(int(x, 16) << 4)+int(y, 16) for x, y in zip(s[0::2], s[1::2])]
+    return list(h2b(s))
 
 
 def i2h(s: List[int]) -> hexstr:
     """convert from a list of integers to a string of hex nibbles"""
-    return hexstr(''.join(['%02x' % (x) for x in s]))
+    return hexstr(bytes(s).hex())
 
 
 def h2s(s: Hexstr) -> str:
